@@ -66,10 +66,11 @@ def compare_companies(org_name_messy, org_name_clean, threshold = SIMILARITY_DIS
     # as the brute force method computes the distances between all pairs of points in the dataset.
 
     # n_neighbors is set to 1 as we are only concerned with pulling the closest company name
+    # n_jobs is set to run to allow process to run in parallel using all processors
 
     nbrs = NearestNeighbors(n_neighbors=1,
-                            metric='cosine',
-                            algorithm='brute',
+                           # metric='cosine',
+                           # algorithm='brute',
                             n_jobs=-1).fit(tfidf)
 
     
